<script setup>
    import { computed, onMounted, onUnmounted, ref } from 'vue';

    const props = defineProps({
        title: {
            type: String,
            default: '',
        },
        message: {
            type: String,
            default: '',
        },
        hover: {
            type: Boolean,
            default: false,
        },
        corner: {
            type: Boolean,
            default: true,
        },
        position: {
            type: String,
            default: '',
        },
        offset: {
            type: Number,
            default: 0,
        },

    });

    const cornerClasses = computed(() => {
        if (props.corner === true) {

            return 'fixed bottom-7 right-0 p-2';

        }else{

            if (props.corner === false) {

                if (props.position === 'bottom') {

                    return 'absolute left-0 -bottom-2 right-0';

                }else if (props.position === 'top') {

                    return 'absolute left-0 right-0 -top-2';

                }else if (props.position === 'left') {

                    return 'absolute -left-2 top-0 bottom-0';

                }else if (props.position === 'right') {

                    return 'absolute -right-2 top-0 bottom-0';

                }
            }
        }

        return 'absolute inset-0';
    });

    const positionClasses = computed(() => {

        if (props.corner === false) {

            if (props.position === 'bottom') {

                return 'translate-y-full notification-arrow-bottom';

            }else if (props.position === 'top') {

                return '-translate-y-full notification-arrow-top';

            }else if (props.position === 'left') {

                return '-translate-x-full notification-arrow-left';

            }else if (props.position === 'right') {

                return 'translate-x-full notification-arrow-right';

            }

        }

        return '';

    });

</script>

<style scoped>
.notification-arrow-bottom::before {
  content: '';
  position: absolute;
  top: -11px;
  left: calc(50% - 2.5px);
  border-width: 5px;
  border-style: solid;
  border-color: transparent transparent rgba(175, 175, 175, 0.75) transparent;
  transform: rotate(0deg);
}

.notification-arrow-top::before {
  content: '';
  position: absolute;
  bottom: -11px;
  left: calc(50% - 2.5px);
  border-width: 5px;
  border-style: solid;
  border-color: transparent transparent rgba(175, 175, 175, 0.75) transparent;
  transform: rotate(180deg);
}

.notification-arrow-left::before {
  content: '';
  position: absolute;
  right: -11px;
  top: calc(50% - 2.5px);
  border-width: 5px;
  border-style: solid;
  border-color: transparent transparent rgba(175, 175, 175, 0.75) transparent;
  transform: rotate(90deg);
}

.notification-arrow-right::before {
  content: '';
  position: absolute;
  left: -11px;
  top: calc(50% - 2.5px);
  border-width: 5px;
  border-style: solid;
  border-color: transparent transparent rgba(175, 175, 175, 0.75) transparent;
  transform: rotate(-90deg);
}

.transition-enter-active, .transition-leave-active {
  transition: opacity 0.4s;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
}
.transition-enter-from, .transition-leave-to {
  opacity: 0;
}
</style>

<template>
    <div class="relative transition-container cursor-pointer" @mouseenter="onMouseEnter" @mouseleave="onMouseLeave">
        <slot/>
        <transition name="transition">
            <div :class="[cornerClasses]" class="flex justify-center items-center z-[250] " v-if="isHover || props.hover">
                <div v-if="props.title != '' || props.message != ''" :class="[positionClasses]" class="rounded-md baltoro-notification flex flex-col px-2 py-1 border-0">
                    <a v-if="props.title != ''" class="text-cyan-text text-left text-sm w-full px-1 py-1 whitespace-nowrap">{{ props.title }}</a>
                    <div v-if="props.title != '' && props.message != ''" class="w-full border-gray-semimedium border-t"></div>
                    <a v-if="props.message != ''" class="text-gray-light text-left text-xs w-full px-1 py-1 max-w-[20rem] h-fit whitespace-normal">{{ props.message }}</a>
                </div>
            </div>
        </transition>
    </div>
</template>

<script>

export default {
    data() {
        return {
        isHover: false,
        };
    },
    methods: {
        onMouseEnter() {
            this.isHover = true;
        },
        onMouseLeave() {
            this.isHover = false;
        },

    },
}
</script>


